Index: /trunk/psLib/src/astronomy/psMetadata.c
===================================================================
--- /trunk/psLib/src/astronomy/psMetadata.c	(revision 1988)
+++ /trunk/psLib/src/astronomy/psMetadata.c	(revision 1989)
@@ -12,6 +12,6 @@
 *  @author Ross Harman, MHPCC
 *
-*  @version $Revision: 1.29 $ $Name: not supported by cvs2svn $
-*  @date $Date: 2004-10-06 01:06:20 $
+*  @version $Revision: 1.30 $ $Name: not supported by cvs2svn $
+*  @date $Date: 2004-10-06 23:27:27 $
 *
 *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -335,9 +335,12 @@
     }
 
-    // Add all items to metadata collection's list, even if they have the same metadata item names
-    if(!psListAdd( mdList, location, metadataItem )) {
-        psError( __func__, "Couldn't add metadata item to metadata collection list. Name: %s",
-                 metadataItem->name );
-        return false;
+    // Add items to metadata collection's list, even if they have the same metadata item names. Folder nodes
+    // (PS_META_ITEM_SET metadata items) are not added, since the metadata list is flat.
+    if(metadataItem->type != PS_META_ITEM_SET) {
+        if(!psListAdd(mdList, location, metadataItem)) {
+            psError( __func__, "Couldn't add metadata item to metadata collection list. Name: %s",
+                     metadataItem->name );
+            return false;
+        }
     }
 
Index: /trunk/psLib/src/collections/psMetadata.c
===================================================================
--- /trunk/psLib/src/collections/psMetadata.c	(revision 1988)
+++ /trunk/psLib/src/collections/psMetadata.c	(revision 1989)
@@ -12,6 +12,6 @@
 *  @author Ross Harman, MHPCC
 *
-*  @version $Revision: 1.29 $ $Name: not supported by cvs2svn $
-*  @date $Date: 2004-10-06 01:06:20 $
+*  @version $Revision: 1.30 $ $Name: not supported by cvs2svn $
+*  @date $Date: 2004-10-06 23:27:27 $
 *
 *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -335,9 +335,12 @@
     }
 
-    // Add all items to metadata collection's list, even if they have the same metadata item names
-    if(!psListAdd( mdList, location, metadataItem )) {
-        psError( __func__, "Couldn't add metadata item to metadata collection list. Name: %s",
-                 metadataItem->name );
-        return false;
+    // Add items to metadata collection's list, even if they have the same metadata item names. Folder nodes
+    // (PS_META_ITEM_SET metadata items) are not added, since the metadata list is flat.
+    if(metadataItem->type != PS_META_ITEM_SET) {
+        if(!psListAdd(mdList, location, metadataItem)) {
+            psError( __func__, "Couldn't add metadata item to metadata collection list. Name: %s",
+                     metadataItem->name );
+            return false;
+        }
     }
 
Index: /trunk/psLib/src/types/psMetadata.c
===================================================================
--- /trunk/psLib/src/types/psMetadata.c	(revision 1988)
+++ /trunk/psLib/src/types/psMetadata.c	(revision 1989)
@@ -12,6 +12,6 @@
 *  @author Ross Harman, MHPCC
 *
-*  @version $Revision: 1.29 $ $Name: not supported by cvs2svn $
-*  @date $Date: 2004-10-06 01:06:20 $
+*  @version $Revision: 1.30 $ $Name: not supported by cvs2svn $
+*  @date $Date: 2004-10-06 23:27:27 $
 *
 *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -335,9 +335,12 @@
     }
 
-    // Add all items to metadata collection's list, even if they have the same metadata item names
-    if(!psListAdd( mdList, location, metadataItem )) {
-        psError( __func__, "Couldn't add metadata item to metadata collection list. Name: %s",
-                 metadataItem->name );
-        return false;
+    // Add items to metadata collection's list, even if they have the same metadata item names. Folder nodes
+    // (PS_META_ITEM_SET metadata items) are not added, since the metadata list is flat.
+    if(metadataItem->type != PS_META_ITEM_SET) {
+        if(!psListAdd(mdList, location, metadataItem)) {
+            psError( __func__, "Couldn't add metadata item to metadata collection list. Name: %s",
+                     metadataItem->name );
+            return false;
+        }
     }
 
